pub enum EncodingOrdering {
Sort,
Keep,
}Expand description
Describes whether the original declaration cares about (re-)ordering the elements or whether their encoding is to be applied in the order of definition (struct fields) or appearance (vec)
Variants